[![npm version](https://badge.fury.io/js/%40taimos%2Fcdk-construct-alexa-skill.svg)](https://badge.fury.io/js/%40taimos%2Fcdk-construct-alexa-skill)
[![PyPI version](https://badge.fury.io/py/taimos.cdk-construct-alexa-skill.svg)](https://badge.fury.io/py/taimos.cdk-construct-alexa-skill)

# A CDK L3 Construct for an Alexa Skill backend

## Installation

You can install the library into your project using npm or pip.

```bash
npm install @taimos/cdk-construct-alexa-skill

pip3 install taimos.cdk-construct-alexa-skill
```

# Contributing

We welcome community contributions and pull requests.

# License

The CDK construct library is distributed under the [Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0).

See [LICENSE](./LICENSE) for more information.
